@@ -10,6 +10,7 @@ def search(
     query: Q = None,
     sources: List = [],
     highlight: Dict = {},
+    sort: str = None
     extras: Dict = {}
 ):
 
@@ -33,10 +34,12 @@ def search(
 
     _s = Search(index = index).extra(**extras).query(query)
 
-    if len(highlights.keys()) > 0:
+    if len(highlight.keys()) > 0:
         _s = _s.highlight(field, **highlight)
     if len(sources) > 0:
         _s = _s.source(sources)
+    if not sort is None:
+        _s = _s.sort(sort)
 
     resp = _s.execute()
     
